use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.002005
eval "use Test::Spelling 0.12; use Pod::Wordlist::hanekomu; 1" or die $@;

set_spell_cmd('aspell list');
add_stopwords(<DATA>);
all_pod_files_spelling_ok('bin', 'lib');
__DATA__
backpan
colour
cpan
cpanm
exe
INI
login
optimizations
transactional
unmark
unregister
unregistering
unregisters
Jeffrey
Thalhammer
Imaginative
Software
Systems
lib
App
Pinto
Command
verify
register
pull
stacks
lock
add
delete
init
pin
rename
props
version
list
manual
diff
statistics
migrate
new
kill
unlock
copy
clean
nop
install
default
log
unpin
